==> billogram-foundation-3.11.1.tgz: package/modules/components/checkbox/SwitchContainer.jest.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Switch from './Switch';
import SwitchContainer, { changeType } from './SwitchContainer';

import checkboxChange from './redux/checkboxChange';
import checkboxState from './redux/checkboxState';

import createStore from '../../test-utils/createStore';


const block = purebem.of('test-checkbox');
// Used to click the lever. Far from ideal, but at least the tests will fail if the style is refactored.
const leverElement = block('content-lever');

const clickLever = (checkbox) => {
    const lever = TestUtils.findRenderedDOMComponentWithClass(checkbox, leverElement);
    const node = ReactDOM.findDOMNode(lever);

    TestUtils.Simulate.click(node);
};

const TestCheckbox = Switch({
    block,
    displayName: 'TestCheckbox'
});

const TestSwitchContainer = SwitchContainer({
    Component: TestCheckbox
});

const path = 'condition';
const root = 'test';
const actionTypePrefix = 'TEST-CHECKBOX';

test('should dispatch change event on change', () => {
    const store = createStore({
        test: {
            condition: checkboxState()
        }
    });

    const provider = TestUtils.renderIntoDocument(
        <Provider store={ store }>
            <TestSwitchContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    clickLever(provider);

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(checkboxChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: true
    }));

});

==> billogram-foundation-3.13.10.tgz: package/modules/components/checkbox/SwitchContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import Switch from './Switch';
import SwitchContainer, { changeType } from './SwitchContainer';

import checkboxChange from './redux/checkboxChange';
import checkboxState from './redux/checkboxState';

import createStore from '../../test-utils/createStore';


const TestSwitch = Switch({
    block: purebem.of('test-checkbox'),
    displayName: 'TestSwitch'
});

const TestSwitchContainer = SwitchContainer({
    Component: TestSwitch
});

const actionTypePrefix = 'TEST-CHECKBOX';
const path = 'component';
const root = 'test';

test('should dispatch change event on change', () => {
    const store = createStore({
        [root]: {
            [path]: checkboxState()
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestSwitchContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find('TestSwitchLever').simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(checkboxChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: true
    }));

});

test('should read value from store', () => {
    const store = createStore({
        [root]: {
            [path]: checkboxState({ value: true })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestSwitchContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    expect(provider.find(TestSwitch).prop('value')).toBe(true);
});
